@@ -24,32 +24,32 @@
 static int rsa_ossl_public_encrypt(int flen, const unsigned char *from,
                                   unsigned char *to, RSA *rsa, int padding);
 static int rsa_ossl_private_encrypt(int flen, const unsigned char *from,
-                                   unsigned char *to, RSA *rsa, int padding);
+    unsigned char *to, RSA *rsa, int padding);
 static int rsa_ossl_public_decrypt(int flen, const unsigned char *from,
-                                  unsigned char *to, RSA *rsa, int padding);
+    unsigned char *to, RSA *rsa, int padding);
 static int rsa_ossl_private_decrypt(int flen, const unsigned char *from,
-                                   unsigned char *to, RSA *rsa, int padding);
+    unsigned char *to, RSA *rsa, int padding);
 static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *i, RSA *rsa,
-                           BN_CTX *ctx);
+    BN_CTX *ctx);
 static int rsa_ossl_init(RSA *rsa);
 static int rsa_ossl_finish(RSA *rsa);
 static RSA_METHOD rsa_pkcs1_ossl_meth = {
     "OpenSSL PKCS#1 RSA",
     rsa_ossl_public_encrypt,
-    rsa_ossl_public_decrypt,     /* signature verification */
-    rsa_ossl_private_encrypt,    /* signing */
+    rsa_ossl_public_decrypt, /* signature verification */
+    rsa_ossl_private_encrypt, /* signing */
     rsa_ossl_private_decrypt,
     rsa_ossl_mod_exp,
-    BN_mod_exp_mont,            /* XXX probably we should not use Montgomery
-                                 * if e == 3 */
+    BN_mod_exp_mont, /* XXX probably we should not use Montgomery
+                      * if e == 3 */
     rsa_ossl_init,
     rsa_ossl_finish,
-    RSA_FLAG_FIPS_METHOD,       /* flags */
+    RSA_FLAG_FIPS_METHOD, /* flags */
     NULL,
-    0,                          /* rsa_sign */
-    0,                          /* rsa_verify */
-    NULL,                       /* rsa_keygen */
-    NULL                        /* rsa_multi_prime_keygen */
+    0, /* rsa_sign */
+    0, /* rsa_verify */
+    NULL, /* rsa_keygen */
+    NULL /* rsa_multi_prime_keygen */
 };
 
 static const RSA_METHOD *default_RSA_meth = &rsa_pkcs1_ossl_meth;
@@ -75,7 +75,7 @@ const RSA_METHOD *RSA_null_method(void)
 }
 
 static int rsa_ossl_public_encrypt(int flen, const unsigned char *from,
-                                  unsigned char *to, RSA *rsa, int padding)
+    unsigned char *to, RSA *rsa, int padding)
 {
     BIGNUM *f, *ret;
     int i, num = 0, r = -1;
@@ -115,12 +115,12 @@ static int rsa_ossl_public_encrypt(int flen, const unsigned char *from,
     switch (padding) {
     case RSA_PKCS1_PADDING:
         i = ossl_rsa_padding_add_PKCS1_type_2_ex(rsa->libctx, buf, num,
-                                                 from, flen);
+            from, flen);
         break;
     case RSA_PKCS1_OAEP_PADDING:
         i = ossl_rsa_padding_add_PKCS1_OAEP_mgf1_ex(rsa->libctx, buf, num,
-                                                    from, flen, NULL, 0,
-                                                    NULL, NULL);
+            from, flen, NULL, 0,
+            NULL, NULL);
         break;
     case RSA_NO_PADDING:
         i = RSA_padding_add_none(buf, num, from, flen);
@@ -143,11 +143,11 @@ static int rsa_ossl_public_encrypt(int flen, const unsigned char *from,
 
     if (rsa->flags & RSA_FLAG_CACHE_PUBLIC)
         if (!BN_MONT_CTX_set_locked(&rsa->_method_mod_n, rsa->lock,
-                                    rsa->n, ctx))
+                rsa->n, ctx))
             goto err;
 
     if (!rsa->meth->bn_mod_exp(ret, f, rsa->e, rsa->n, ctx,
-                               rsa->_method_mod_n))
+            rsa->_method_mod_n))
         goto err;
 
     /*
@@ -155,7 +155,7 @@ static int rsa_ossl_public_encrypt(int flen, const unsigned char *from,
      * the length of the modulus.
      */
     r = BN_bn2binpad(ret, to, num);
- err:
+err:
     BN_CTX_end(ctx);
     BN_CTX_free(ctx);
     OPENSSL_clear_free(buf, num);
@@ -197,13 +197,13 @@ static BN_BLINDING *rsa_get_blinding(RSA *rsa, int *local, BN_CTX *ctx)
         ret = rsa->mt_blinding;
     }
 
- err:
+err:
     CRYPTO_THREAD_unlock(rsa->lock);
     return ret;
 }
 
 static int rsa_blinding_convert(BN_BLINDING *b, BIGNUM *f, BIGNUM *unblind,
-                                BN_CTX *ctx)
+    BN_CTX *ctx)
 {
     if (unblind == NULL) {
         /*
@@ -227,7 +227,7 @@ static int rsa_blinding_convert(BN_BLINDING *b, BIGNUM *f, BIGNUM *unblind,
 }
 
 static int rsa_blinding_invert(BN_BLINDING *b, BIGNUM *f, BIGNUM *unblind,
-                               BN_CTX *ctx)
+    BN_CTX *ctx)
 {
     /*
      * For local blinding, unblind is set to NULL, and BN_BLINDING_invert_ex
@@ -243,7 +243,7 @@ static int rsa_blinding_invert(BN_BLINDING *b, BIGNUM *f, BIGNUM *unblind,
 
 /* signing */
 static int rsa_ossl_private_encrypt(int flen, const unsigned char *from,
-                                   unsigned char *to, RSA *rsa, int padding)
+    unsigned char *to, RSA *rsa, int padding)
 {
     BIGNUM *f, *ret, *res;
     int i, num = 0, r = -1;
@@ -298,7 +298,7 @@ static int rsa_ossl_private_encrypt(int flen, const unsigned char *from,
 
     if (rsa->flags & RSA_FLAG_CACHE_PUBLIC)
         if (!BN_MONT_CTX_set_locked(&rsa->_method_mod_n, rsa->lock,
-                                    rsa->n, ctx))
+                rsa->n, ctx))
             goto err;
 
     if (!(rsa->flags & RSA_FLAG_NO_BLINDING)) {
@@ -318,11 +318,7 @@ static int rsa_ossl_private_encrypt(int flen, const unsigned char *from,
             goto err;
     }
 
-    if ((rsa->flags & RSA_FLAG_EXT_PKEY) ||
-        (rsa->version == RSA_ASN1_VERSION_MULTI) ||
-        ((rsa->p != NULL) &&
-         (rsa->q != NULL) &&
-         (rsa->dmp1 != NULL) && (rsa->dmq1 != NULL) && (rsa->iqmp != NULL))) {
+    if ((rsa->flags & RSA_FLAG_EXT_PKEY) || (rsa->version == RSA_ASN1_VERSION_MULTI) || ((rsa->p != NULL) && (rsa->q != NULL) && (rsa->dmp1 != NULL) && (rsa->dmq1 != NULL) && (rsa->iqmp != NULL))) {
         if (!rsa->meth->rsa_mod_exp(ret, f, rsa, ctx))
             goto err;
     } else {
@@ -339,7 +335,7 @@ static int rsa_ossl_private_encrypt(int flen, const unsigned char *from,
         BN_with_flags(d, rsa->d, BN_FLG_CONSTTIME);
 
         if (!rsa->meth->bn_mod_exp(ret, f, d, rsa->n, ctx,
-                                   rsa->_method_mod_n)) {
+                rsa->_method_mod_n)) {
             BN_free(d);
             goto err;
         }
@@ -367,7 +363,7 @@ static int rsa_ossl_private_encrypt(int flen, const unsigned char *from,
      * the length of the modulus.
      */
     r = BN_bn2binpad(res, to, num);
- err:
+err:
     BN_CTX_end(ctx);
     BN_CTX_free(ctx);
     OPENSSL_clear_free(buf, num);
@@ -375,7 +371,7 @@ static int rsa_ossl_private_encrypt(int flen, const unsigned char *from,
 }
 
 static int rsa_ossl_private_decrypt(int flen, const unsigned char *from,
-                                   unsigned char *to, RSA *rsa, int padding)
+    unsigned char *to, RSA *rsa, int padding)
 {
     BIGNUM *f, *ret;
     int j, num = 0, r = -1;
@@ -438,7 +434,7 @@ static int rsa_ossl_private_decrypt(int flen, const unsigned char *from,
 
     if (rsa->flags & RSA_FLAG_CACHE_PUBLIC)
         if (!BN_MONT_CTX_set_locked(&rsa->_method_mod_n, rsa->lock,
-                                    rsa->n, ctx))
+                rsa->n, ctx))
             goto err;
 
     if (!(rsa->flags & RSA_FLAG_NO_BLINDING)) {
@@ -459,11 +455,7 @@ static int rsa_ossl_private_decrypt(int flen, const unsigned char *from,
     }
 
     /* do the decrypt */
-    if ((rsa->flags & RSA_FLAG_EXT_PKEY) ||
-        (rsa->version == RSA_ASN1_VERSION_MULTI) ||
-        ((rsa->p != NULL) &&
-         (rsa->q != NULL) &&
-         (rsa->dmp1 != NULL) && (rsa->dmq1 != NULL) && (rsa->iqmp != NULL))) {
+    if ((rsa->flags & RSA_FLAG_EXT_PKEY) || (rsa->version == RSA_ASN1_VERSION_MULTI) || ((rsa->p != NULL) && (rsa->q != NULL) && (rsa->dmp1 != NULL) && (rsa->dmq1 != NULL) && (rsa->iqmp != NULL))) {
         if (!rsa->meth->rsa_mod_exp(ret, f, rsa, ctx))
             goto err;
     } else {
@@ -479,7 +471,7 @@ static int rsa_ossl_private_decrypt(int flen, const unsigned char *from,
         }
         BN_with_flags(d, rsa->d, BN_FLG_CONSTTIME);
         if (!rsa->meth->bn_mod_exp(ret, f, d, rsa->n, ctx,
-                                   rsa->_method_mod_n)) {
+                rsa->_method_mod_n)) {
             BN_free(d);
             goto err;
         }
@@ -533,7 +525,7 @@ static int rsa_ossl_private_decrypt(int flen, const unsigned char *from,
 
 /* signature verification */
 static int rsa_ossl_public_decrypt(int flen, const unsigned char *from,
-                                  unsigned char *to, RSA *rsa, int padding)
+    unsigned char *to, RSA *rsa, int padding)
 {
     BIGNUM *f, *ret;
     int i, num = 0, r = -1;
@@ -589,11 +581,11 @@ static int rsa_ossl_public_decrypt(int flen, const unsigned char *from,
 
     if (rsa->flags & RSA_FLAG_CACHE_PUBLIC)
         if (!BN_MONT_CTX_set_locked(&rsa->_method_mod_n, rsa->lock,
-                                    rsa->n, ctx))
+                rsa->n, ctx))
             goto err;
 
     if (!rsa->meth->bn_mod_exp(ret, f, rsa->e, rsa->n, ctx,
-                               rsa->_method_mod_n))
+            rsa->_method_mod_n))
         goto err;
 
     if ((padding == RSA_X931_PADDING) && ((bn_get_words(ret)[0] & 0xf) != 12))
@@ -621,7 +613,7 @@ static int rsa_ossl_public_decrypt(int flen, const unsigned char *from,
     if (r < 0)
         ERR_raise(ERR_LIB_RSA, RSA_R_PADDING_CHECK_FAILED);
 
- err:
+err:
     BN_CTX_end(ctx);
     BN_CTX_free(ctx);
     OPENSSL_clear_free(buf, num);
@@ -652,7 +644,7 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
 #ifndef FIPS_MODULE
     if (rsa->version == RSA_ASN1_VERSION_MULTI
         && ((ex_primes = sk_RSA_PRIME_INFO_num(rsa->prime_infos)) <= 0
-             || ex_primes > RSA_MAX_PRIME_NUM - 2))
+            || ex_primes > RSA_MAX_PRIME_NUM - 2))
         goto err;
 #endif
 
@@ -667,11 +659,11 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
          * BN_FLG_CONSTTIME flag
          */
         if (!(BN_with_flags(factor, rsa->p, BN_FLG_CONSTTIME),
-              BN_MONT_CTX_set_locked(&rsa->_method_mod_p, rsa->lock,
-                                     factor, ctx))
+                BN_MONT_CTX_set_locked(&rsa->_method_mod_p, rsa->lock,
+                    factor, ctx))
             || !(BN_with_flags(factor, rsa->q, BN_FLG_CONSTTIME),
-                 BN_MONT_CTX_set_locked(&rsa->_method_mod_q, rsa->lock,
-                                        factor, ctx))) {
+                BN_MONT_CTX_set_locked(&rsa->_method_mod_q, rsa->lock,
+                    factor, ctx))) {
             BN_free(factor);
             goto err;
         }
@@ -692,14 +684,14 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
 
         smooth = (rsa->meth->bn_mod_exp == BN_mod_exp_mont)
 #ifndef FIPS_MODULE
-                 && (ex_primes == 0)
+            && (ex_primes == 0)
 #endif
-                 && (BN_num_bits(rsa->q) == BN_num_bits(rsa->p));
+            && (BN_num_bits(rsa->q) == BN_num_bits(rsa->p));
     }
 
     if (rsa->flags & RSA_FLAG_CACHE_PUBLIC)
         if (!BN_MONT_CTX_set_locked(&rsa->_method_mod_n, rsa->lock,
-                                    rsa->n, ctx))
+                rsa->n, ctx))
             goto err;
 
     if (smooth) {
@@ -723,10 +715,10 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
              *    r1 = r1^dmp1 mod p
              */
             || !BN_mod_exp_mont_consttime_x2(m1, m1, rsa->dmq1, rsa->q,
-                                             rsa->_method_mod_q,
-                                             r1, r1, rsa->dmp1, rsa->p,
-                                             rsa->_method_mod_p,
-                                             ctx)
+                rsa->_method_mod_q,
+                r1, r1, rsa->dmp1, rsa->p,
+                rsa->_method_mod_p,
+                ctx)
             /* r1 = (r1 - m1) mod p */
             /*
              * bn_mod_sub_fixed_top is not regular modular subtraction,
@@ -739,7 +731,7 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
             /* r1 = r1 * iqmp mod p */
             || !bn_to_mont_fixed_top(r1, r1, rsa->_method_mod_p, ctx)
             || !bn_mul_mont_fixed_top(r1, r1, rsa->iqmp, rsa->_method_mod_p,
-                                      ctx)
+                ctx)
             /* r0 = r1 * q + m1 */
             || !bn_mul_fixed_top(r0, r1, rsa->q, ctx)
             || !bn_mod_add_fixed_top(r0, r0, m1, rsa->n))
@@ -770,7 +762,7 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
 
             /* compute r1^dmq1 mod q */
             if (!rsa->meth->bn_mod_exp(m1, r1, dmq1, rsa->q, ctx,
-                                       rsa->_method_mod_q)) {
+                    rsa->_method_mod_q)) {
                 BN_free(c);
                 BN_free(dmq1);
                 goto err;
@@ -796,7 +788,7 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
 
         /* compute r1^dmp1 mod p */
         if (!rsa->meth->bn_mod_exp(r0, r1, dmp1, rsa->p, ctx,
-                                   rsa->_method_mod_p)) {
+                rsa->_method_mod_p)) {
             BN_free(dmp1);
             goto err;
         }
@@ -933,16 +925,16 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
     }
 #endif
 
- tail:
+tail:
     if (rsa->e && rsa->n) {
         if (rsa->meth->bn_mod_exp == BN_mod_exp_mont) {
             if (!BN_mod_exp_mont(vrfy, r0, rsa->e, rsa->n, ctx,
-                                 rsa->_method_mod_n))
+                    rsa->_method_mod_n))
                 goto err;
         } else {
             bn_correct_top(r0);
             if (!rsa->meth->bn_mod_exp(vrfy, r0, rsa->e, rsa->n, ctx,
-                                       rsa->_method_mod_n))
+                    rsa->_method_mod_n))
                 goto err;
         }
         /*
@@ -956,7 +948,7 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
         if (BN_is_zero(vrfy)) {
             bn_correct_top(r0);
             ret = 1;
-            goto err;   /* not actually error */
+            goto err; /* not actually error */
         }
         if (!BN_mod(vrfy, vrfy, rsa->n, ctx))
             goto err;
@@ -976,7 +968,7 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
             BN_with_flags(d, rsa->d, BN_FLG_CONSTTIME);
 
             if (!rsa->meth->bn_mod_exp(r0, I, d, rsa->n, ctx,
-                                       rsa->_method_mod_n)) {
+                    rsa->_method_mod_n)) {
                 BN_free(d);
                 goto err;
             }
@@ -994,7 +986,7 @@ static int rsa_ossl_mod_exp(BIGNUM *r0, const BIGNUM *I, RSA *rsa, BN_CTX *ctx)
      */
     bn_correct_top(r0);
     ret = 1;
- err:
+err:
     BN_CTX_end(ctx);
     return ret;
 }
